@@ -10,7 +10,7 @@
 pub mod stm32f4 {
     pub mod flash;
     pub mod gpio;
-    #[cfg(feature = "stm32f412")]
+    #[cfg(any(feature = "stm32f412", feature = "stm32f446"))]
     pub mod qspi;
     pub mod rcc;
     pub mod serial;
@@ -29,6 +29,12 @@ pub mod efm32gg11b {
     pub mod clocks;
 }
 
+#[cfg(feature = "max3263_any")]
+#[macro_use]
+pub mod max3263 {
+    pub mod flash;
+}
+
 pub mod led;
 
 /// Drivers for the Micron manufacturer (e.g. external flash).
