@@ -14,10 +14,15 @@ pub use stm32f4::stm32f412 as stm32pac;
 pub use stm32f4::stm32f429 as stm32pac;
 #[cfg(feature = "stm32f469")]
 pub use stm32f4::stm32f469 as stm32pac;
+#[cfg(feature = "stm32f446")]
+pub use stm32f4::stm32f446 as stm32pac;
 
 #[cfg(feature = "efm32gg11b_any")]
 pub use efm32gg11b as efm32pac;
 
+#[cfg(feature = "max3263_any")]
+pub use max3263x as max32pac;
+
 #[macro_use]
 pub mod utilities {
     pub mod bitwise;
